.. _baseimageobjects:

************************
Base ImageObject Classes
************************

.. currentmodule:: drizzlepac.imageObject 

.. autoclass:: baseImageObject
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: imageObject
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: WCSObject
   :members:
   :undoc-members:
   :show-inheritance:
